@@ -1,6 +1,6 @@
 /*
 getscn.c - implementation of the elf_getscn(3) function.
-Copyright (C) 1995, 1996 Michael Riepe <michael@stud.uni-hannover.de>
+Copyright (C) 1995 - 1998 Michael Riepe <michael@stud.uni-hannover.de>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
@@ -19,6 +19,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include <private.h>
 
+#ifndef lint
+static const char rcsid[] = "@(#) $Id: getscn.c,v 1.3 1998/06/12 19:42:27 michael Exp $";
+#endif /* lint */
+
 Elf_Scn*
 elf_getscn(Elf *elf, size_t index) {
     Elf_Scn *scn;
